==> segment-wrapper-3.24.3.tgz: package/lib/middlewares/source/pageReferrer.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
export var referrerState = {
  spaReferrer: '',
  referrer: ''
};
/**
 * Useful wrapper around document and window objects
 */

export var utils = {
  /**
   * @returns {string} The referrer of the document
   */
  getDocumentReferrer: function getDocumentReferrer() {
    return document.referrer;
  },

  /**
   * @returns {string} The actual location with protocol, domain and pathname
   */
  getActualLocation: function getActualLocation() {
    var _window$location = window.location,
        origin = _window$location.origin,
        pathname = _window$location.pathname;
    return "" + origin + pathname;
  }
};
/**
 * Get the correct page referrer for SPA navigations
 * @returns {string}  referrer
 */

export var getPageReferrer = function getPageReferrer(_temp) {
  var _ref = _temp === void 0 ? {} : _temp,
      _ref$isPageTrack = _ref.isPageTrack,
      isPageTrack = _ref$isPageTrack === void 0 ? false : _ref$isPageTrack;

  var referrer = referrerState.referrer,
      spaReferrer = referrerState.spaReferrer; // if we're a page, we should use the new referrer that was calculated with the previous location
  // if we're a track, we should use the previous referrer, as the location hasn't changed yet

  var referrerToUse = isPageTrack ? referrer : spaReferrer; // as a fallback for page and tracks, we must use always the document.referrer
  // because some sites could not be using `page` or a `track` could be done
  // even before the first page

  return referrerToUse || utils.getDocumentReferrer();
};
/**
 * Update page referrer for SPA navigations
 */

export var updatePageReferrer = function updatePageReferrer() {
  referrerState.spaReferrer = getPageReferrer({
    isPageTrack: true
  }); // mutate actualReferrer with what will be the new referrer

  referrerState.referrer = utils.getActualLocation();
};
/**
 * @param {object} params
 * @param {{obj: {context: object }}} params.payload
 * @param {function} params.next
 * @returns {void}
 */

export var pageReferrer = function pageReferrer(_ref2) {
  var payload = _ref2.payload,
      next = _ref2.next;
  var context = payload.obj.context;
  var isPageTrack = context.isPageTrack;
  var referrer = getPageReferrer({
    isPageTrack: isPageTrack
  });
  payload.obj.context = _extends({}, context, {
    page: _extends({}, context.page, {
      referrer: referrer
    })
  }); // update page referrer only if it's a page event

  isPageTrack && updatePageReferrer();
  next(payload);
};

==> segment-wrapper-3.50.0.tgz: package/lib/middlewares/source/pageReferrer.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
export var referrerState = {
  spaReferrer: '',
  referrer: ''
};

/**
 * Useful wrapper around document and window objects
 */
export var utils = {
  /**
   * @returns {string} The referrer of the document
   */
  getDocumentReferrer: function getDocumentReferrer() {
    return document.referrer;
  },
  /**
   * @returns {string} The actual location with protocol, domain and pathname
   */
  getActualLocation: function getActualLocation() {
    var _window$location = window.location,
      origin = _window$location.origin,
      pathname = _window$location.pathname;
    return "" + origin + pathname;
  },
  /**
   * @returns {string} The actual location with protocol, domain and pathname
   */
  getActualQueryString: function getActualQueryString() {
    var search = window.location.search;
    return search;
  }
};

/**
 * Get the correct page referrer for SPA navigations
 * @returns {string}  referrer
 */
export var getPageReferrer = function getPageReferrer(_temp) {
  var _ref = _temp === void 0 ? {} : _temp,
    _ref$isPageTrack = _ref.isPageTrack,
    isPageTrack = _ref$isPageTrack === void 0 ? false : _ref$isPageTrack;
  var referrer = referrerState.referrer,
    spaReferrer = referrerState.spaReferrer;
  // if we're a page, we should use the new referrer that was calculated with the previous location
  // if we're a track, we should use the previous referrer, as the location hasn't changed yet
  var referrerToUse = isPageTrack ? referrer : spaReferrer;
  // as a fallback for page and tracks, we must use always the document.referrer
  // because some sites could not be using `page` or a `track` could be done
  // even before the first page
  return referrerToUse || utils.getDocumentReferrer();
};

/**
 * Update page referrer for SPA navigations
 */
export var updatePageReferrer = function updatePageReferrer() {
  referrerState.spaReferrer = getPageReferrer({
    isPageTrack: true
  });
  // mutate actualReferrer with what will be the new referrer
  referrerState.referrer = utils.getActualLocation();
};

/**
 * @param {object} params
 * @param {{obj: {context: object }}} params.payload
 * @param {function} params.next
 * @returns {void}
 */
export var pageReferrer = function pageReferrer(_ref2) {
  var payload = _ref2.payload,
    next = _ref2.next;
  var context = payload.obj.context;
  var isPageTrack = context.isPageTrack;
  var referrer = getPageReferrer({
    isPageTrack: isPageTrack
  });
  payload.obj.context = _extends({}, context, {
    page: _extends({}, context.page, {
      referrer: referrer
    })
  });

  // update page referrer only if it's a page event
  isPageTrack && updatePageReferrer();
  next(payload);
};
